@@ -952,8 +952,10 @@ static void ProcessVPBMessage(uint16_t mess[], unsigned short board)
 	    {
 		VPBREG	&reg = *vpb_c->vpbreg(board);
 		if( reg.model == VPB_V4PCI ) {
-			reg.toneg[objtrack_id_to_handle(TONEOBJ,mess[2],board)]
-			    ->SignalCompletion();
+			unsigned short brd;
+			unsigned short prt;
+			maphndletodev(objtrack_id_to_handle(TONEOBJ,mess[2],board), &brd, &prt);
+			reg.toneg[prt]->SignalCompletion();
 		} else
 			reg.toneg[mess[2]]->SignalCompletion();
 		break;
