@@ -183,7 +183,7 @@ void settonedet(int chdev, const VPB_DETECT &d)
 
 	if( ! exists )
 		index = numtd[chdev]++;
-	if(numtd[chdev] >= VPB_MD)
+	if(numtd[chdev] > VPB_MD)
 		throw VpbException("settonedet: too many detectors");
 
 	// validate tone parameters
