@@ -920,7 +920,10 @@ void VTCore::SetHookState( int port, HookState hookstate )
 		break;
 	}
 	//XXX Should this throw if an error occurs?
-	vtcore_sethook(m_reg.cardtypnum, port, hookstate);
+	int ret = vtcore_sethook(m_reg.cardtypnum, port, hookstate);
+	if( ret < 0 )
+		mprintf("[%d/%d] FAILED to set hook state %u: (%d) %s\n",
+			m_reg.cardnum, port, hookstate, ret, strerror(ret));
 } //}}}
 
 void VTCore::WaitForTxEmpty( int port )
@@ -1148,11 +1151,9 @@ void VTCore::HostDSPOpen()
 
 	if (pci_fd == 0){
 		pci_fd = open(pcidev,O_RDWR);
-		if(pci_fd == -1){
-			printf("Couldnt open VTCore device node (%s): %s\n",
-			       pcidev, strerror(errno));
-			exit(1);
-		}
+		if(pci_fd == -1)
+			throw VpbException("Couldn't open VTCore device node (%s): %s\n",
+					   pcidev, strerror(errno));
 	}
 
 	m_reg.toned = new TD*[m_reg.numch];
