@@ -335,10 +335,13 @@ static int __ping_arm(struct openpci *card)
 { //{{{
 	int i;
 	int pong=0;
+	int pong_count = 3;
 
-	while(pong != 0x02){
+	while( pong_count ) {
 		outb(0x02, PIB(1)); ++card->armbout; HTXF_WAIT();
 		HRXF_WAIT(); pong = inb(PIB(1)); ++card->armbin;
+		if( pong == 0x02 ) --pong_count;
+		else               pong_count = 3;
 		dbginfo(5,card->cardnum, "ping_arm returned %x", pong);
 	}
 	while(pong == 0x02){
@@ -2594,3 +2597,4 @@ MODULE_AUTHOR(DRIVER_AUTHOR);
 MODULE_VERSION(VT_VERSION);
 MODULE_LICENSE("GPL");
 
+// vi:sts=8:sw=8:ts=8:noet:foldmethod=marker
